@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2011,2014,2016,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2011,2014,2016,2018,2019,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -53,6 +53,8 @@
 /**                                 to   : 28 jun 2011     **/
 /**                # Version 6.0  : from : 28 jun 2011     **/
 /**                                 to   : 15 may 2018     **/
+/**                # Version 7.0  : from : 21 aug 2019     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -60,7 +62,7 @@
 **  The defines and includes.
 */
 
-#define ARCH_BUILD
+#define SCOTCH_ARCH_BUILD
 
 #include "module.h"
 #include "common.h"
@@ -121,7 +123,8 @@ archDecoArchBuild (
 Arch * restrict const       tgtarchptr,           /*+ Decomposition architecture to build    +*/
 const Graph * const         tgtgrafptr,           /*+ Source graph modeling the architecture +*/
 const VertList * const      tgtlistptr,           /*+ Subset of source graph vertices        +*/
-const Strat * const         mapstrat)             /*+ Bipartitioning strategy                +*/
+const Strat * const         mapstrat,             /*+ Bipartitioning strategy                +*/
+Context * const             contptr)              /*+ Execution context                      +*/
 {
   Arch                              archdat;      /* Variable-sized architecture for bipartitioning */
   ArchDom                           domsub0;      /* Temporary space for subdomain 0                */
@@ -159,8 +162,6 @@ const Strat * const         mapstrat)             /*+ Bipartitioning strategy
   if (termdomnbr == 0)                            /* If nothing to do */
     return (0);
 
-  intRandInit ();                                 /* Initialize random generator */
-
   invedlosiz = (tgtedlotax != NULL) ? tgtgrafptr->edgenbr : 0;
   if ((memAllocGroup ((void **) (void *)
                       &jobtab,     (size_t) (termdomnbr * sizeof (ArchDecoBuildJob)),
@@ -208,6 +209,7 @@ const Strat * const         mapstrat)             /*+ Bipartitioning strategy
   actgrafdat.veextax = NULL;                      /* No external gain array      */
   actgrafdat.parttax = actparttax;                /* Set global auxiliary arrays */
   actgrafdat.frontab = actfrontab;
+  actgrafdat.contptr = contptr;                   /* Use same context for all jobs  */
   joblink = NULL;                                 /* Initialize job list            */
   if (jobtab[0].grafdat.vertnbr > 1) {            /* If job is worth bipartitioning */
     jobtab[0].joblink = joblink;                  /* Add initial job to list        */
