@@ -1,4 +1,4 @@
-/* Copyright 2015,2016,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2015,2016,2018,2019,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -42,7 +42,7 @@
 /**   DATES      : # Version 6.0  : from : 13 mar 2015     **/
 /**                                 to   : 15 may 2018     **/
 /**                # Version 7.0  : from : 13 sep 2019     **/
-/**                                 to   : 13 sep 2019     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -50,8 +50,6 @@
 **  The defines and includes.
 */
 
-#define ARCH_SUB
-
 #include "module.h"
 #include "common.h"
 #include "arch.h"
