@@ -1,4 +1,4 @@
-/* Copyright 2007-2014,2018-2020 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007-2014,2018-2020,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,7 +44,7 @@
 /**              : # Version 6.0  : from : 11 sep 2011     **/
 /**                                 to   : 31 aug 2019     **/
 /**              : # Version 7.0  : from : 27 aug 2019     **/
-/**                                 to   : 14 jan 2020     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -52,7 +52,7 @@
 **  The defines and includes.
 */
 
-#define BDGRAPH_BIPART_ML
+#define SCOTCH_BDGRAPH_BIPART_ML
 
 #include "module.h"
 #include "common.h"
