@@ -1,4 +1,4 @@
-/* Copyright 2007-2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007-2012,2018,2021 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,6 +45,8 @@
 /**                                 to   : 20 feb 2011     **/
 /**                # Version 6.0  : from : 03 apr 2012     **/
 /**                                 to   : 21 may 2018     **/
+/**                # Version 7.0  : from : 01 oct 2021     **/
+/**                                 to   : 08 oct 2021     **/
 /**                                                        **/
 /**   NOTES      : # This code derives from the code of    **/
 /**                  vdgraph_separate_bd.c in version      **/
@@ -84,7 +86,8 @@ const Gnum                        distmax,        /*+ Maximum distance from sepa
 Gnum * restrict const             vnumgsttax,     /*+ Flag or index array to fill                              +*/
 Gnum * restrict const             bandvertlvlptr, /*+ Pointer to based start index of last level               +*/
 Gnum * restrict const             bandvertlocptr, /*+ Pointer to bandvertlocnnd                                +*/
-Gnum * restrict const             bandedgelocptr) /*+ Pointer to bandedgelocnbr                                +*/
+Gnum * restrict const             bandedgelocptr, /*+ Pointer to bandedgelocnbr                                +*/
+Context *                         contptr)        /*+ Execution context                                        +*/
 {
   Gnum                    vertlocnnd;
   Gnum                    vrcvdatsiz;             /* Sizes of data send and receive arrays */
@@ -319,7 +322,8 @@ const Gnum                        distmax,        /*+ Maximum distance from sepa
 Gnum * restrict const             vnumgsttax,     /*+ Flag or index array to fill                              +*/
 Gnum * restrict const             bandvertlvlptr, /*+ Pointer to based start index of last level               +*/
 Gnum * restrict const             bandvertlocptr, /*+ Pointer to bandvertlocnnd                                +*/
-Gnum * restrict const             bandedgelocptr) /*+ Pointer to bandedgelocnbr                                +*/
+Gnum * restrict const             bandedgelocptr, /*+ Pointer to bandedgelocnbr                                +*/
+Context *                         contptr)        /*+ Execution context                                        +*/
 {
   Gnum                    vertlocnnd;
   Gnum                    vrcvdatsiz;             /* Sizes of data send and receive arrays */
@@ -343,6 +347,7 @@ Gnum * restrict const             bandedgelocptr) /*+ Pointer to bandedgelocnbr
   Gnum                    bandvertlocnnd;
   Gnum                    bandedgelocnbr;
   Gnum                    distval;
+  Gnum                    deteval;                /* Flag set if deterministic behavior    */
 #ifdef SCOTCH_DEBUG_DGRAPH1
   Gnum                    reduloctab[3];
   Gnum                    reduglbtab[3];
@@ -395,6 +400,8 @@ Gnum * restrict const             bandedgelocptr) /*+ Pointer to bandedgelocnbr
     return (1);
   }
 
+  contextValuesGetInt (contptr, CONTEXTOPTIONNUMDETERMINISTIC, &deteval);
+
   for (procngbnum = 0, nrcvdspnum = nsnddspnum = procngbnxt = 0; /* Build communication index arrays */
        procngbnum < procngbnbr; procngbnum ++) {
     int                 procglbnum;
@@ -522,12 +529,13 @@ Gnum * restrict const             bandedgelocptr) /*+ Pointer to bandedgelocnbr
       int               statsiz;
       int               o;
 
-#ifdef SCOTCH_DETERMINISTIC
-      procngbnum = vrcvreqnbr - 1;
-      o = MPI_Wait (&nrcvreqtab[procngbnum], &statdat);
-#else /* SCOTCH_DETERMINISTIC */
-      o = MPI_Waitany (procngbnbr, nrcvreqtab, &procngbnum, &statdat);
-#endif /* SCOTCH_DETERMINISTIC */
+      if (deteval) {
+        procngbnum = vrcvreqnbr - 1;
+        o = MPI_Wait (&nrcvreqtab[procngbnum], &statdat);
+      }
+      else
+        o = MPI_Waitany (procngbnbr, nrcvreqtab, &procngbnum, &statdat);
+
       if ((o != MPI_SUCCESS) ||
           (MPI_Get_count (&statdat, GNUM_MPI, &statsiz) != MPI_SUCCESS)) {
         errorPrint (DGRAPHBANDGROWNSTR "Ptop: communication error (5)");
