@@ -1,4 +1,4 @@
-/* Copyright 2007-2011,2014,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007-2011,2014,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -46,6 +46,8 @@
 /**                                 to   : 28 sep 2014     **/
 /**                # Version 6.1  : from : 18 jun 2021     **/
 /**                                 to   : 19 jun 2021     **/
+/**                # Version 7.0  : from : 14 sep 2021     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -53,8 +55,6 @@
 **  The defines and includes.
 */
 
-#define DGRAPH
-
 #include "module.h"
 #include "common.h"
 #include "dgraph.h"
@@ -103,7 +103,7 @@ MPI_Datatype                  datatype)
 
   if (MPI_Comm_split (orggrafptr->proccomm, fldproccol, fldprocnum, &fldproccomm) != MPI_SUCCESS) {
     errorPrint ("dgraphFold: communication error");
-    return     (1);
+    return (1);
   }
 
   o = dgraphFold2 (orggrafptr, partval, fldgrafptr, fldproccomm, orgdataptr, flddataptr, datatype);
@@ -122,6 +122,9 @@ const void * restrict const   orgdataptr,         /*+ Un-based array of data whi
 void ** const                 flddataptr,         /*+ Un-based array of data which must be kept, e.g. coarmulttab  +*/
 MPI_Datatype                  datatype)
 {
+  Gnum * restrict               orgvertloctax;    /* Pointer to (possible compacted) vertex array                     */ 
+  Gnum * restrict               orgedgeloctax;    /* Pointer to (possible compacted) edge array                       */
+  Gnum * restrict               orgedloloctax;    /* Pointer to (possible compacted) edge load array                  */
   int                           fldcommtypval;    /* Type of communication for this process                           */
   DgraphFoldCommData * restrict fldcommdattab;    /* Array of two communication data                                  */
   Gnum *                        fldcommvrttab;    /* Starting global send indices of communications [norestrict]      */
@@ -147,12 +150,17 @@ MPI_Datatype                  datatype)
 
   const Gnum                    orgprocvrtbas = orggrafptr->procvrttab[orggrafptr->proclocnum];
 
-#ifdef SCOTCH_DEBUG_DGRAPH2
-  if (orggrafptr->vendloctax != (orggrafptr->vertloctax + 1)) {
-    errorPrint ("dgraphFold2: graph must be compact");
-    return     (1);
+  if (orggrafptr->vendloctax != (orggrafptr->vertloctax + 1)) { /* If graph is not compact */
+    if (dgraphCompact2 (orggrafptr, &orgvertloctax, &orgedgeloctax, &orgedloloctax) != 0) {
+      errorPrint ("dgraphFold2: cannot compact graph");
+      return (1);
+    }
+  }
+  else {                                          /* Graph is compact; take arrays as is */
+    orgvertloctax = orggrafptr->vertloctax;
+    orgedgeloctax = orggrafptr->edgeloctax;
+    orgedloloctax = orggrafptr->edloloctax;
   }
-#endif /* SCOTCH_DEBUG_DGRAPH2 */
 
   fldprocglbnbr = (orggrafptr->procglbnbr + 1) / 2;
   if (partval == 1) {
@@ -173,11 +181,11 @@ MPI_Datatype                  datatype)
 #ifdef SCOTCH_DEBUG_DGRAPH2
     if (fldgrafptr == NULL) {
       errorPrint ("dgraphFold2: invalid parameters (1)");
-      return     (1);
+      return (1);
     }
     if (fldproccomm == MPI_COMM_NULL) {
       errorPrint ("dgraphFold2: invalid parameters (2)");
-      return     (1);
+      return (1);
     }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
 
@@ -221,7 +229,7 @@ MPI_Datatype                  datatype)
       }
       else {                                      /* Process is a sender receiver                */
         fldvertlocnbr = fldcommvrttab[0] - orgprocvrtbas; /* Communications will remove vertices */
-        fldedgelocsiz = orggrafptr->vertloctax[fldvertlocnbr + orggrafptr->baseval] - orggrafptr->baseval; /* Exact number of edges */
+        fldedgelocsiz = orgvertloctax[fldvertlocnbr + orggrafptr->baseval] - orggrafptr->baseval; /* Exact number of edges */
 
         fldgrafptr->edgelocnbr =
         fldgrafptr->edgelocsiz = fldedgelocsiz;
@@ -239,7 +247,7 @@ MPI_Datatype                  datatype)
                fldgrafptr->vnumloctax -= orggrafptr->baseval,
                fldgrafptr->vendloctax  = fldgrafptr->vertloctax + 1, /* Folded graph is compact */
                fldgrafptr->veloloctax  = ((orggrafptr->veloloctax != NULL) ? (fldgrafptr->veloloctax - orggrafptr->baseval) : NULL),
-               fldedlolocsiz = ((orggrafptr->edloloctax != NULL) ? fldedgelocsiz : 0),
+               fldedlolocsiz = ((orgedloloctax != NULL) ? fldedgelocsiz : 0),
                (fldgrafptr->edgeloctax = memAlloc ((fldedgelocsiz + fldedlolocsiz) * sizeof (Gnum))) == NULL) { /* Allocate single array for both edge arrays */
         errorPrint ("dgraphFold2: out of memory (3)");
         cheklocval = 1;
@@ -259,7 +267,7 @@ MPI_Datatype                  datatype)
 #ifdef SCOTCH_DEBUG_HDGRAPH2
     if (fldproccomm != MPI_COMM_NULL) {
       errorPrint ("dgraphFold2: invalid parameters (3)");
-      return     (1);
+      return (1);
     }
 #endif /* SCOTCH_DEBUG_HDGRAPH2 */
 
@@ -314,9 +322,9 @@ MPI_Datatype                  datatype)
       vertsndnbr  = fldcommdattab[i].vertnbr;
 
       fldvertidxtab[i] = vertsndbas;
-      fldedgeidxtab[i] = orggrafptr->vertloctax[vertsndbas];
+      fldedgeidxtab[i] = orgvertloctax[vertsndbas];
       fldedgecnptab[i] =                          /* Save fldedgecnttab in temporary array to read it while MPI communication in progress */
-      fldedgecnttab[i] = orggrafptr->vertloctax[vertsndbas + vertsndnbr] - orggrafptr->vertloctax[vertsndbas]; /* Graph is compact        */
+      fldedgecnttab[i] = orgvertloctax[vertsndbas + vertsndnbr] - orgvertloctax[vertsndbas]; /* Graph is compact        */
       if (MPI_Isend (&fldedgecnptab[i], 1, GNUM_MPI, fldcommdattab[i].procnum,
                      TAGFOLD + TAGVLBLLOCTAB, orggrafptr->proccomm, &requtab[requnbr ++]) != MPI_SUCCESS) {
         errorPrint ("dgraphFold2: communication error (2)");
@@ -326,14 +334,14 @@ MPI_Datatype                  datatype)
     commnbr = i;
 
     for (i = 0; (i < commnbr) && (cheklocval == 0); i ++) {
-      if (MPI_Isend (orggrafptr->vertloctax + fldvertidxtab[i], fldcommdattab[i].vertnbr, GNUM_MPI, fldcommdattab[i].procnum,
+      if (MPI_Isend (orgvertloctax + fldvertidxtab[i], fldcommdattab[i].vertnbr, GNUM_MPI, fldcommdattab[i].procnum,
                      TAGFOLD + TAGVERTLOCTAB, orggrafptr->proccomm, &requtab[requnbr ++]) != MPI_SUCCESS) {
         errorPrint ("dgraphFold2: communication error (3)");
         cheklocval = 1;
       }
     }
     for (i = 0; (i < commnbr) && (cheklocval == 0); i ++) {
-      if (MPI_Isend (orggrafptr->edgeloctax + fldedgeidxtab[i], fldedgecnttab[i], GNUM_MPI, fldcommdattab[i].procnum,
+      if (MPI_Isend (orgedgeloctax + fldedgeidxtab[i], fldedgecnttab[i], GNUM_MPI, fldcommdattab[i].procnum,
                      TAGFOLD + TAGEDGELOCTAB, orggrafptr->proccomm, &requtab[requnbr ++]) != MPI_SUCCESS) {
         errorPrint ("dgraphFold2: communication error (4)");
         cheklocval = 1;
@@ -352,8 +360,8 @@ MPI_Datatype                  datatype)
       int               procsndnum;               /* Rank of process to send to */
 
       procsndnum = fldcommdattab[i].procnum;
-      if ((orggrafptr->edloloctax != NULL) &&
-          (MPI_Isend (orggrafptr->edloloctax + fldedgeidxtab[i], fldedgecnttab[i], GNUM_MPI, procsndnum,
+      if ((orgedloloctax != NULL) &&
+          (MPI_Isend (orgedloloctax + fldedgeidxtab[i], fldedgecnttab[i], GNUM_MPI, procsndnum,
                       TAGFOLD + TAGEDLOLOCTAB, orggrafptr->proccomm, &requtab[requnbr ++]) != MPI_SUCCESS)) {
         errorPrint ("dgraphFold2: communication error (6)");
         cheklocval = 1;
@@ -388,8 +396,6 @@ MPI_Datatype                  datatype)
     int                 procngbmax;
     int                 i;
 
-    const Gnum * restrict const orgedgeloctax = orggrafptr->edgeloctax;
-
     fldgrafptr->procvrttab = fldgrafptr->procdsptab; /* Graph does not have holes                                 */
     fldgrafptr->procdsptab[0] = orggrafptr->baseval; /* Build private data of folded graph and array              */
     for (fldprocnum = 0; fldprocnum < fldprocglbnbr; fldprocnum ++) { /* New subdomain indices start from baseval */
@@ -424,7 +430,7 @@ MPI_Datatype                  datatype)
 
       MPI_Waitall (commnbr, &requtab[DGRAPHFOLDTAGENBR * commmax], MPI_STATUSES_IGNORE);
 
-      for (i = 0, fldedgelocbas = orggrafptr->vertloctax[orggrafptr->vertlocnnd]; (i < commnbr) && (cheklocval == 0); i ++) {
+      for (i = 0, fldedgelocbas = orgvertloctax[orggrafptr->vertlocnnd]; (i < commnbr) && (cheklocval == 0); i ++) {
         fldedgeidxtab[i] = fldedgelocbas;
         fldedgelocbas += fldedgecnttab[i];
 
@@ -446,7 +452,7 @@ MPI_Datatype                  datatype)
           }
         }
       }
-      if (orggrafptr->edloloctax != NULL) {
+      if (orgedloloctax != NULL) {
         fldgrafptr->edloloctax = fldgrafptr->edgeloctax + fldgrafptr->edgelocnbr; /* Set start index of edge load array */
 
         for (i = 0; (i < commnbr) && (cheklocval == 0); i ++) {
@@ -496,7 +502,7 @@ MPI_Datatype                  datatype)
         }
       }
 
-      fldedgelocnnd = orggrafptr->vertloctax[orggrafptr->vertlocnnd];
+      fldedgelocnnd = orgvertloctax[orggrafptr->vertlocnnd];
       fldvelolocsum = orggrafptr->velolocsum;     /* In case there are vertex loads, we keep all of existing load */
     }
     else {                                        /* Receiver process is also a sender     */
@@ -510,8 +516,8 @@ MPI_Datatype                  datatype)
              fldvertlocnum < orgvertlocnnd; fldvertlocnum ++)
           fldvelolocsum += orggrafptr->veloloctax[fldvertlocnum];
       }
-      fldedgelocnnd = orggrafptr->vertloctax[orgvertlocnnd]; /* Reorder remaining local part of edge array */
-      if (orggrafptr->edloloctax != NULL)
+      fldedgelocnnd = orgvertloctax[orgvertlocnnd]; /* Reorder remaining local part of edge array */
+      if (orgedloloctax != NULL)
         fldgrafptr->edloloctax = fldgrafptr->edgeloctax + fldgrafptr->edgelocnbr; /* Set start index of edge load array */
 
       commnbr = 0;                                /* Turn sender-receiver into normal receiver without any communications to perform */
@@ -561,10 +567,9 @@ MPI_Datatype                  datatype)
       memCpy (fldgrafptr->veloloctax + orggrafptr->baseval, /* Copy local part of vertex load array */
               orggrafptr->veloloctax + orggrafptr->baseval, orgvertlocnbr * sizeof (Gnum));
 
-    if (orggrafptr->edloloctax != NULL)           /* If original graph has edge loads             */
+    if (orgedloloctax != NULL)                    /* If original graph has edge loads             */
       memCpy (fldgrafptr->edloloctax + orggrafptr->baseval, /* Copy local part of edge load array */
-              orggrafptr->edloloctax + orggrafptr->baseval,
-              (orggrafptr->vertloctax[orgvertlocnnd] - orggrafptr->baseval) * sizeof (Gnum));
+              orgedloloctax + orggrafptr->baseval, (orgvertloctax[orgvertlocnnd] - orggrafptr->baseval) * sizeof (Gnum));
 
     if (orggrafptr->vnumloctax != NULL)           /* If original graph has vertex numbers             */
       memCpy (fldgrafptr->vnumloctax + orggrafptr->baseval, /* Copy local part of vertex number array */
@@ -578,8 +583,8 @@ MPI_Datatype                  datatype)
         fldgrafptr->vnumloctax[fldvertlocnum] = fldvertlocadj ++;
     }
 
-    memCpy (fldgrafptr->vertloctax + orggrafptr->baseval, /* Copy local part of vertex array, since it is compact     */
-            orggrafptr->vertloctax + orggrafptr->baseval, orgvertlocnbr * sizeof (Gnum)); /* Last value is not copied */
+    memCpy (fldgrafptr->vertloctax + orggrafptr->baseval, /* Copy local part of vertex array, since it is compact */
+            orgvertloctax + orggrafptr->baseval, orgvertlocnbr * sizeof (Gnum)); /* Last value is not copied      */
     fldgrafptr->vertloctax[fldvertlocnbr + orggrafptr->baseval] = fldgrafptr->edgelocnbr + orggrafptr->baseval;
 
     if (orgdataptr != NULL)                       /* If additional data present */
@@ -629,7 +634,7 @@ MPI_Datatype                  datatype)
         MPI_Get_count (&statdat, GNUM_MPI, &fldedgercvnbr);
         if (fldedgercvnbr != fldedgecnttab[j]) {
           errorPrint  ("dgraphFold2: internal error (1)");
-          return      (1);
+          return (1);
         }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
 
@@ -654,7 +659,7 @@ MPI_Datatype                  datatype)
 #ifdef SCOTCH_DEBUG_DGRAPH2
           if (fldedgelocnum >= (fldgrafptr->edgelocnbr + orggrafptr->baseval)) {
             errorPrint  ("dgraphFold2: internal error (2)");
-            return      (1);
+            return (1);
           }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
 
@@ -708,7 +713,7 @@ MPI_Datatype                  datatype)
       Gnum                fldedgeloctmp;
 
       fldedgeloctmp = fldgrafptr->edgelocnbr;
-      if (orggrafptr->edloloctax != NULL) {
+      if (orgedloloctax != NULL) {
         fldedgeloctmp *= 2;
         if (MPI_Waitall (commnbr, &requtab[DGRAPHFOLDTAGEDLO * commmax], MPI_STATUSES_IGNORE) != MPI_SUCCESS) { /* Wait for edge load sub-arrays */
           errorPrint ("dgraphFold2: communication error (19)");
@@ -718,7 +723,7 @@ MPI_Datatype                  datatype)
 
       fldgrafptr->edgeloctax  = memRealloc (fldgrafptr->edgeloctax + orggrafptr->baseval, fldedgeloctmp * sizeof (Gnum));
       fldgrafptr->edgeloctax -= orggrafptr->baseval;
-      if (orggrafptr->edloloctax != NULL)
+      if (orgedloloctax != NULL)
         fldgrafptr->edloloctax = fldgrafptr->edgeloctax + fldgrafptr->edgelocnbr;
     }
 
@@ -730,14 +735,14 @@ MPI_Datatype                  datatype)
     if (dgraphBuild4 (fldgrafptr) != 0) {
       errorPrint ("dgraphFold2: cannot build folded graph");
       dgraphExit (fldgrafptr);
-      return     (1);
+      return (1);
     }
 
 #ifdef SCOTCH_DEBUG_DGRAPH2
     if (dgraphCheck (fldgrafptr) != 0) {          /* Check graph consistency; vnumloctab is not checked so no need to wait for it */
       errorPrint ("dgraphFold2: internal error (3)");
       dgraphExit (fldgrafptr);
-      return     (1);
+      return (1);
     }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
   }
@@ -750,6 +755,8 @@ MPI_Datatype                  datatype)
   }
 
   memFree (fldvertidxtab);                        /* Free group leader including request array */
+  if (orgvertloctax != orggrafptr->vertloctax)
+    memFree (orgvertloctax + orggrafptr->baseval);
 
 #ifdef SCOTCH_DEBUG_DGRAPH1                       /* Communication cannot be merged with a useful one */
   if (MPI_Allreduce (&cheklocval, &chekglbval, 1, MPI_INT, MPI_MAX, orggrafptr->proccomm) != MPI_SUCCESS) {
