@@ -1,4 +1,4 @@
-/* Copyright 2009,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2009,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,6 +43,8 @@
 /**                                 to   : 22 apr 2009     **/
 /**                # Version 6.1  : from : 27 dec 2021     **/
 /**                                 to   : 27 dec 2021     **/
+/**                # Version 7.0  : from : 17 jan 2023     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -50,8 +52,6 @@
 ** The defines and includes.
 */
 
-#define DGRAPH_MATCH
-
 #include "module.h"
 #include "common.h"
 #include "dgraph.h"
