@@ -1,4 +1,4 @@
-/* Copyright 2008,2009,2012,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2008,2009,2012,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -47,7 +47,7 @@
 /**                # Version 6.1  : from : 27 dec 2021     **/
 /**                                 to   : 27 dec 2021     **/
 /**                # Version 7.0  : from : 22 oct 2021     **/
-/**                                 to   : 22 oct 2021     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -55,8 +55,6 @@
 ** The defines and includes.
 */
 
-#define DGRAPH_MATCH
-
 #include "module.h"
 #include "common.h"
 #include "context.h"
