@@ -1,4 +1,4 @@
-/* Copyright 2007,2008,2013 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2008,2013,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,6 +44,8 @@
 /**                                 to   : 28 sep 2008     **/
 /**                # Version 6.0  : from : 10 oct 2013     **/
 /**                                 to   : 10 oct 2013     **/
+/**                # Version 7.0  : from : 18 jan 2023     **/
+/**                                 to   : 18 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -51,8 +53,6 @@
 **  The defines and includes.
 */
 
-#define DORDER
-
 #include "module.h"
 #include "common.h"
 #include "dgraph.h"
