@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2009,2014,2015,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2009,2014,2015,2018,2020,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -50,11 +50,13 @@
 /**                # Version 5.1  : from : 01 oct 2009     **/
 /**                                 to   : 01 oct 2009     **/
 /**                # Version 6.0  : from : 04 aug 2014     **/
-/**                                 to   : 06 jun 2018     **/
+/**                                 to   : 27 jan 2020     **/
+/**                # Version 7.0  : from : 05 may 2019     **/
+/**                                 to   : 19 jan 2023     **/
 /**                                                        **/
 /**   NOTES      : # Pre-hashing proves itself extremely   **/
 /**                  efficient, since for graphs that      **/
-/**                  will be compressed very few writes    **/
+/**                  will be compressed, very few writes   **/
 /**                  will be performed in the pre-hashing  **/
 /**                  array, and for others, for which pre- **/
 /**                  hashing costs much more, it will save **/
@@ -66,7 +68,7 @@
 **  The defines and includes.
 */
 
-#define HGRAPH_ORDER_CP
+#define SCOTCH_HGRAPH_ORDER_CP
 
 #include "module.h"
 #include "common.h"
@@ -414,6 +416,8 @@ loop_failed: ;
   coargrafdat.s.edgenbr = coaredgenum - coargrafdat.s.baseval;
   coargrafdat.enlosum   =
   coargrafdat.enohnbr   = coargrafdat.s.edgenbr - 2 * (coaredgenum - coarenohnnd);
+  coargrafdat.levlnum   = finegrafptr->levlnum;   /* Keep level  */
+  coargrafdat.contptr   = finegrafptr->contptr;   /* Use context */
 
   if (finevelotax != NULL) {                      /* If fine graph has vertex loads */
     memSet (coargrafdat.s.velotax + coargrafdat.s.baseval, 0, coargrafdat.s.vertnbr * sizeof (Gnum));
@@ -459,8 +463,14 @@ loop_failed: ;
     return     (1);
   }
 #endif /* SCOTCH_DEBUG_ORDER2 */
+#ifdef SCOTCH_PTHREAD
+  pthread_mutex_lock (&fineordeptr->mutedat);
+#endif /* SCOTCH_PTHREAD */
   fineordeptr->treenbr += coarordedat.treenbr - 1; /* Adjust number of tree nodes    */
   fineordeptr->cblknbr += coarordedat.cblknbr - 1; /* Adjust number of column blocks */
+#ifdef SCOTCH_PTHREAD
+  pthread_mutex_unlock (&fineordeptr->mutedat);
+#endif /* SCOTCH_PTHREAD */
 
   coarvpostax = coargrafdat.s.verttax;            /* Re-cycle verttab (not velotab as may be merged with coarvsiztab) */
   coarperitax = coarperitab - coargrafdat.s.baseval;
