@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,7 +44,7 @@
 /**                # Version 5.0  : from : 25 jul 2007     **/
 /**                                 to   : 25 jul 2007     **/
 /**                # Version 7.0  : from : 26 apr 2021     **/
-/**                                 to   : 26 apr 2021     **/
+/**                                 to   : 20 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -52,8 +52,6 @@
 **  The defines and includes.
 */
 
-#define HMESH_ORDER_BL
-
 #include "module.h"
 #include "common.h"
 #include "parser.h"
