@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2009,2011,2014,2018,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2009,2011,2014,2018,2019,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -69,6 +69,8 @@
 /**                                 to   : 21 jun 2019     **/
 /**                # Version 6.1  : from : 28 jun 2021     **/
 /**                                 to   : 28 jun 2021     **/
+/**                # Version 7.0  : from : 25 aug 2019     **/
+/**                                 to   : 20 jan 2023     **/
 /**                                                        **/
 /**   NOTES      : # This code is a complete rewrite of    **/
 /**                  the original code of kgraphMapRb(),   **/
@@ -80,7 +82,7 @@
 **  The defines and includes.
 */
 
-#define KGRAPH_MAP_RB_MAP
+#define SCOTCH_KGRAPH_MAP_RB_MAP
 
 #include "module.h"
 #include "common.h"
@@ -117,7 +119,8 @@ static
 int
 kgraphMapRbMapPoolInit (
 KgraphMapRbMapPoolData * restrict const poolptr,
-const KgraphMapRbData * restrict const  dataptr)
+const KgraphMapRbData * restrict const  dataptr,
+Context * const                         contptr)
 {
   int                 flagval;
 
@@ -166,6 +169,7 @@ const KgraphMapRbData * restrict const  dataptr)
   }
 
   poolptr->flagval = flagval;
+  poolptr->contptr = contptr;
 
   return (0);
 }
@@ -380,7 +384,7 @@ KgraphMapRbMapJob * const       jobptr)           /* Job to be added */
   switch (poolptr->polival) {                     /* Set job priority value */
     case KGRAPHMAPRBPOLIRANDOM :
       jobptr->prioval =
-      jobptr->priolvl = intRandVal (INTVALMAX);
+      jobptr->priolvl = contextIntRandVal (poolptr->contptr, INTVALMAX);
       break;
     case KGRAPHMAPRBPOLILEVEL   :
     case KGRAPHMAPRBPOLINGLEVEL :
@@ -431,7 +435,7 @@ const GraphPart                 partval)
   switch (poolptr->polival) {                     /* Set job priority value */
     case KGRAPHMAPRBPOLIRANDOM :
       prioval =
-      priolvl = intRandVal (INTVALMAX);
+      priolvl = contextIntRandVal (poolptr->contptr, INTVALMAX);
       break;
     case KGRAPHMAPRBPOLILEVEL :
       priolvl = joboldptr->priolvl + 1;
@@ -443,13 +447,11 @@ const GraphPart                 partval)
     case KGRAPHMAPRBPOLINGSIZE :
       prioval = jobnewptr->grafdat.vertnbr;
       break;
-#ifdef SCOTCH_DEBUG_KGRAPH2
     default :
       errorPrint ("kgraphMapRbMapPoolUpdt1: unknown job selection policy");
       jobnewptr->prioval = 0;
       jobnewptr->priolvl = 0;
       return;
-#endif /* SCOTCH_DEBUG_KGRAPH2 */
   }
 
   jobnewptr->prioval = prioval;
@@ -597,7 +599,7 @@ KgraphMapRbMapJob * const       jobnewptr1)
     switch (poolptr->polival) {                   /* Set job priority value */
       case KGRAPHMAPRBPOLIRANDOM :
         prioval =
-        priolvl = intRandVal (INTVALMAX);
+        priolvl = contextIntRandVal (poolptr->contptr, INTVALMAX);
         break;
       case KGRAPHMAPRBPOLILEVEL :
         priolvl = joboldptr->priolvl + 1;
@@ -609,13 +611,11 @@ KgraphMapRbMapJob * const       jobnewptr1)
       case KGRAPHMAPRBPOLINGSIZE :
         prioval = jobnewptr->grafdat.vertnbr;
         break;
-#ifdef SCOTCH_DEBUG_KGRAPH2
       default :
         errorPrint ("kgraphMapRbMapPoolUpdt2: unknown job selection policy");
         jobnewptr->prioval = 0;
         jobnewptr->priolvl = 0;
         return;
-#endif /* SCOTCH_DEBUG_KGRAPH2 */
     }
 
     jobnewptr0->prioval = prioval + 1;            /* TRICK: when processing subdomain 1, subdomain 0 has higher priority value */
@@ -864,7 +864,8 @@ kgraphMapRbMap (
 const KgraphMapRbData * restrict const  dataptr,  /*+ Global mapping data                  +*/
 const Graph * restrict const            grafptr,  /*+ Graph to map, without fixed vertices +*/
 const Anum                              vflonbr,  /*+ Number of fixed vertex load slots    +*/
-KgraphMapRbVflo * restrict const        vflotab)  /*+ Array of fixed vertex load slots     +*/
+KgraphMapRbVflo * restrict const        vflotab,  /*+ Array of fixed vertex load slots     +*/
+Context * const                         contptr)  /*+ Execution context                    +*/
 {
   KgraphMapRbMapPoolData  pooldat;                /* Data for handling jobs and job pools */
   ArchDom                 domnsubtab[2];          /* Subdomains of current job domain     */
@@ -895,7 +896,7 @@ KgraphMapRbVflo * restrict const        vflotab)  /*+ Array of fixed vertex load
   mappptr->domnmax = 1;                           /* Force resizing of job arrays, for debugging */
 #endif /* SCOTCH_DEBUG_KGRAPH2 */
 
-  if (kgraphMapRbMapPoolInit (&pooldat, dataptr) != 0) /* Initialize pool data; done first for kgraphMapRbMapPoolExit() to succeed afterwards */
+  if (kgraphMapRbMapPoolInit (&pooldat, dataptr, contptr) != 0) /* Initialize pool data; done first for kgraphMapRbMapPoolExit() to succeed afterwards */
     return (1);
 
   if ((((pooldat.flagval & KGRAPHMAPRBMAPARCHVAR) == 0) && (archDomSize (mappptr->archptr, &mappptr->domnorg) <= 1)) || /* If single-vertex domain   */
@@ -936,7 +937,7 @@ KgraphMapRbVflo * restrict const        vflotab)  /*+ Array of fixed vertex load
 
       kgraphMapRbVfloSplit (mappptr->archptr, domnsubtab, /* Split fixed vertex load slots, if any */
                             joborgdat.vflonbr, joborgdat.vflotab, vflonbrtab, vflowgttab);
-      if (kgraphMapRbBgraph (dataptr, &actgrafdat, &joborgdat.grafdat, pooldat.mappptr, domnsubtab, vflowgttab) != 0) { /* Create bipartition graph */
+      if (kgraphMapRbBgraph (dataptr, &actgrafdat, &joborgdat.grafdat, pooldat.mappptr, domnsubtab, vflowgttab, contptr) != 0) { /* Create bipartition graph */
         errorPrint ("kgraphMapRbMap: cannot create bipartition graph");
         kgraphMapRbMapPoolExit (&pooldat);        /* Copied graph will be freed as not yet removed */
         return (1);
