@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2009,2011,2014,2015,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2009,2011,2014,2015,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,7 +52,7 @@
 /**                # Version 6.1  : from : 01 nov 2021     **/
 /**                                 to   : 21 nov 2021     **/
 /**                # Version 7.0  : from : 03 may 2019     **/
-/**                                 to   : 05 may 2019     **/
+/**                                 to   : 16 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -60,7 +60,7 @@
 **  The defines and includes.
 */
 
-#define VGRAPH_SEPARATE_ML
+#define SCOTCH_VGRAPH_SEPARATE_ML
 
 #include "module.h"
 #include "common.h"
